AssetGenerator class

Constructors

AssetGenerator({required String skinDir, required List<String> assetDirs, required Map<String, List<String>> qualifiers})

Properties

assetDirs List<String>
final
hashCode int
The hash code for this object.
no setterinherited
qualifiers Map<String, List<String>>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skinDir String
final

Methods

generate() Future<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited